==> owncloud-app-calendar-1%3A1.3.2-3-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/sv.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "Individual" : "Individuell",
    "Group" : "Grupp",
    "Resource" : "Resurs",
    "Room" : "Rum",
    "Unknown" : "Okänt",
    "Required" : "Krävs",
    "Optional" : "Valfritt",
    "Does not attend" : "Kommer inte att delta",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Du är i en okänd tidszon ({tz}), faller tillbaka på UTC",
    "Please create a calendar first." : "Vänlligen skapa en kalender först.",
    "New event" : "Nytt event",
    "Attendees" : "Deltagare",
    "Reminders" : "Påminnelser",
    "Repeating" : "Repetera",
    "When shared show full event" : "När delad visa hela händelsen",
    "When shared show only busy" : "När delad visa endast upptagen",
    "When shared hide this event" : "När delad göm denna händelse",
    "Please add a title!" : "Vänligen lägg till en titel!",
    "Please select a calendar!" : "Vänligen välj en kalender!",
    "Global" : "Global",
    "None" : "Ingen",
    "Every day" : "Varje dag",
    "Every week" : "Varje vecka",
    "Every month" : "Varje månad",
    "Every year" : "Varje år",
    "never" : "aldrig",
    "after" : "efter",
    "At time of event" : "På tid för event",
    "5 minutes before" : "5 minuter före",
    "10 minutes before" : "10 minuter före",
    "15 minutes before" : "15 minuter före",
    "30 minutes before" : "30 minuter före",
    "1 hour before" : "1 timme före",
    "2 hours before" : "2 timmar före",
    "Custom" : "special",
    "Audio" : "Ljud",
    "E Mail" : "E-post",
    "Pop up" : "Pop-up ",
    "sec" : "sek",
    "min" : "min",
    "hours" : "timmar",
    "days" : "dagar",
    "week" : "vecka",
    "before" : "före",
    "start" : "start",
    "end" : "slut",
    "Editing reminders of unknown type not supported." : "Att redigera påminnelser för okända typer stöds inte.",
    "Week {number} of {year}" : "Vecka {number} av {year}",
    "Successfully imported" : "Lyckad importering",
    "Partially imported, 1 failure" : "Delvis importerad, 1 fel",
    "Partially imported, {n} failures" : "Delvis importerad, {n} fel",
    "Audio alarm" : "Ringande alarm",
    "Pop-up" : "Pop-up ",
    "E-Mail" : "E-post",
    "{type} {time} before the event starts" : "{type} {time} före händelsen börjar",
    "{type} {time} before the event ends" : "{type} {time} före händelsen slutar",
    "{type} {time} after the event starts" : "{type} {time} efter händelsen börjar",
    "{type} {time} after the event ends" : "{type} {time} efter händelsen slutar",
    "{type} at the event's start" : "{type} vid händelsens början",
    "{type} at the event's end" : "{type} vid händelsens slut",
    "{type} at {time}" : "{type} vid {time}",
    "{calendar} shared by {owner}" : "{calendar} delad utav {owner}",
    "Title of the Event" : "Rubrik för händelsen",
    "starts" : "börjar",
    "ends" : "slutar",
    "All day Event" : "Heldags evenemang",
    "Delete" : "Ta bort",
    "Cancel" : "Avbryt",
    "More ..." : "Mer ...",
    "Create" : "Skapa",
    "Update" : "Uppdatera",
    "Close" : "Stäng",
    "Location" : "Plats",
    "Description" : "Beskrivning",
    "Export" : "Exportera",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "På grund utav en bug uppströms, så kan inte calendar ge någon support för asset pipeline funktionen.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Var god kontakta din administratör och be denne avaktivera \"asset-pipeline.enable\" inställningen.",
    "Day" : "Dag",
    "Week" : "Vecka",
    "Month" : "Månad",
    "Today" : "Idag",
    "Share Calendar" : "Dela kalender",
    "More" : "Mer",
    "Edit" : "Ändra",
    "CalDAV" : "CalDAV",
    "Share with users or groups" : "Dela med användare eller grupper",
    "can edit" : "kan redigera",
    "group" : "Grupp",
    "New Calendar" : "Ny kalender",
    "Subscriptions" : "Prenumerationer",
    "New Subscription" : "Ny prenumeration",
    "Url" : "Url",
    "Edit event" : "Redigera händelse",
    "Delete Event" : "Radera händelse",
    "Save Event" : "Spara händelse",
    "Time" : "Tid",
    "Type" : "Typ",
    "Relative" : "Relativ",
    "Absolute" : "Absolut",
    "Repeat" : "Upprepa",
    "times every" : "gånger varje",
    "Add" : "Lägg till",
    "E-Mail address of attendee" : "E-mailadress till deltagare",
    "Please add your email address in the personal settings in order to add attendees." : "Vänligen lägg till din e-mailadress i personliga inställningar för att kunna lägga till deltagare",
    "from" : "från",
    "to" : "till",
    "This event's repeating rule is not supported yet." : "Detta events repeteringsregel stöds inte ännu",
    "Support for advanced rules will be added with subsequent updates." : "Support för advancerade regler kommer läggas till i senare uppdateringar.",
    "Reset repeating rule" : "Radera repeteringsregeln",
    "Repeat every ..." : "Repetera varje ...",
    "end repeat ..." : "sluta repetera ...",
    "times" : "gånger",
    "Import Calendars" : "Importera kalender",
    "Import canceled" : "Importering avbruten",
    "Analyzing calendar" : "Analyserar kalender",
    "The file contains objects incompatible with the selected calendar" : "Filen innehåller objekt inkompatibla med den valda kalendern",
    "New calendar" : "Ny kalender",
    "Import scheduled" : "Import schemalagd",
    "Settings" : "Inställningar",
    "Import calendar" : "Importera kalender",
    "No Calendars selected for import" : "Ingen kalender vald för import",
    "Primary CalDAV address" : "Primär CalDAV adress",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adress"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-calendar-1%3A1.3.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/sv.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "Individual" : "Individuell",
    "Group" : "Grupp",
    "Resource" : "Resurs",
    "Room" : "Rum",
    "Unknown" : "Okänt",
    "Required" : "Krävs",
    "Optional" : "Valfritt",
    "Does not attend" : "Kommer inte att delta",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Du är i en okänd tidszon ({tz}), faller tillbaka på UTC",
    "Please create a calendar first." : "Vänlligen skapa en kalender först.",
    "New event" : "Nytt event",
    "Attendees" : "Deltagare",
    "Reminders" : "Påminnelser",
    "Repeating" : "Repetera",
    "When shared show full event" : "När delad visa hela händelsen",
    "When shared show only busy" : "När delad visa endast upptagen",
    "When shared hide this event" : "När delad göm denna händelse",
    "Cancelled" : "Avbruten",
    "Please add a title!" : "Vänligen lägg till en titel!",
    "Please select a calendar!" : "Vänligen välj en kalender!",
    "Global" : "Global",
    "None" : "Ingen",
    "Every day" : "Varje dag",
    "Every week" : "Varje vecka",
    "Every month" : "Varje månad",
    "Every year" : "Varje år",
    "never" : "aldrig",
    "after" : "efter",
    "At time of event" : "På tid för event",
    "5 minutes before" : "5 minuter före",
    "10 minutes before" : "10 minuter före",
    "15 minutes before" : "15 minuter före",
    "30 minutes before" : "30 minuter före",
    "1 hour before" : "1 timme före",
    "2 hours before" : "2 timmar före",
    "Custom" : "special",
    "Audio" : "Ljud",
    "E Mail" : "E-post",
    "Pop up" : "Pop-up ",
    "sec" : "sek",
    "min" : "min",
    "hours" : "timmar",
    "days" : "dagar",
    "week" : "vecka",
    "before" : "före",
    "start" : "start",
    "end" : "slut",
    "Editing reminders of unknown type not supported." : "Att redigera påminnelser för okända typer stöds inte.",
    "Week {number} of {year}" : "Vecka {number} av {year}",
    "Successfully imported" : "Lyckad importering",
    "Partially imported, 1 failure" : "Delvis importerad, 1 fel",
    "Partially imported, {n} failures" : "Delvis importerad, {n} fel",
    "Audio alarm" : "Ringande alarm",
    "Pop-up" : "Pop-up ",
    "E-Mail" : "E-post",
    "{type} {time} before the event starts" : "{type} {time} före händelsen börjar",
    "{type} {time} before the event ends" : "{type} {time} före händelsen slutar",
    "{type} {time} after the event starts" : "{type} {time} efter händelsen börjar",
    "{type} {time} after the event ends" : "{type} {time} efter händelsen slutar",
    "{type} at the event's start" : "{type} vid händelsens början",
    "{type} at the event's end" : "{type} vid händelsens slut",
    "{type} at {time}" : "{type} vid {time}",
    "{calendar} shared by {owner}" : "{calendar} delad utav {owner}",
    "Title of the Event" : "Rubrik för händelsen",
    "starts" : "börjar",
    "ends" : "slutar",
    "All day Event" : "Heldags evenemang",
    "Delete" : "Ta bort",
    "Cancel" : "Avbryt",
    "More ..." : "Mer ...",
    "Create" : "Skapa",
    "Update" : "Uppdatera",
    "Close" : "Stäng",
    "Location" : "Plats",
    "Description" : "Beskrivning",
    "Export" : "Exportera",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "På grund utav en bug uppströms, så kan inte calendar ge någon support för asset pipeline funktionen.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Var god kontakta din administratör och be denne avaktivera \"asset-pipeline.enable\" inställningen.",
    "Day" : "Dag",
    "Week" : "Vecka",
    "Month" : "Månad",
    "Today" : "Idag",
    "Share Calendar" : "Dela kalender",
    "Shared" : "Delad",
    "More" : "Mer",
    "Edit" : "Ändra",
    "Link" : "Länk",
    "Download" : "Ladda ned",
    "Share with users or groups" : "Dela med användare eller grupper",
    "can edit" : "kan redigera",
    "group" : "Grupp",
    "New Calendar" : "Ny kalender",
    "Subscriptions" : "Prenumerationer",
    "New Subscription" : "Ny prenumeration",
    "Url" : "Url",
    "Edit event" : "Redigera händelse",
    "Delete Event" : "Radera händelse",
    "Save Event" : "Spara händelse",
    "Time" : "Tid",
    "Type" : "Typ",
    "Relative" : "Relativ",
    "Absolute" : "Absolut",
    "Repeat" : "Upprepa",
    "times every" : "gånger varje",
    "Add" : "Lägg till",
    "E-Mail address of attendee" : "E-mailadress till deltagare",
    "Please add your email address in the personal settings in order to add attendees." : "Vänligen lägg till din e-mailadress i personliga inställningar för att kunna lägga till deltagare",
    "from" : "från",
    "to" : "till",
    "This event's repeating rule is not supported yet." : "Detta events repeteringsregel stöds inte ännu",
    "Support for advanced rules will be added with subsequent updates." : "Support för advancerade regler kommer läggas till i senare uppdateringar.",
    "Reset repeating rule" : "Radera repeteringsregeln",
    "Repeat every ..." : "Repetera varje ...",
    "end repeat ..." : "sluta repetera ...",
    "times" : "gånger",
    "Import Calendars" : "Importera kalender",
    "Import canceled" : "Importering avbruten",
    "Analyzing calendar" : "Analyserar kalender",
    "The file contains objects incompatible with the selected calendar" : "Filen innehåller objekt inkompatibla med den valda kalendern",
    "New calendar" : "Ny kalender",
    "Import scheduled" : "Import schemalagd",
    "Settings" : "Inställningar",
    "Import calendar" : "Importera kalender",
    "No Calendars selected for import" : "Ingen kalender vald för import",
    "Primary CalDAV address" : "Primär CalDAV adress",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adress"
},
"nplurals=2; plural=(n != 1);");
